@@ -164,10 +164,18 @@ class Media(object):
         section = 'SERVICE:{}'.format(service_id)
         pid_video = CONFIG[section]['pid_video']
         pid_audio = CONFIG[section]['pid_audio']
-        new_filepath = '{root}/{day}/{service_id}/{filename}'.format(
+        new_folder = '{root}/{day}/{service_id}'.format(
             root=CONFIG['APP']['modified_media_folder'],
             day=day,
-            service_id=service_id,
+            service_id=service_id
+            )
+        subprocess.call(
+            shlex.split(
+                'mkdir -p {}'.format(new_folder)
+                )
+            )
+        new_filepath = '{new_folder}/{filename}'.format(
+            new_folder=new_folder,
             filename=self.filename
             )
         if self.filename.startswith('revue_emediaplace'):
@@ -192,12 +200,13 @@ class Media(object):
                 '-y /tmp/v_revue_bluepano.ts'
                 ).format(
                     filepath=self.filepath,
+                    x264=x264,
                     image=image_filepath
                     )
             subprocess.call(shlex.split(cmd))
             # ajouter la bande son
             audio = os.path.join(
-                CONFIG['APP']['images_folder'],
+                CONFIG['APP']['audios_folder'],
                 'audio_emediaplace.aac'
                 )
             cmd = (
@@ -349,29 +358,40 @@ class Media(object):
         """
         duration = self.duration
         schedule = self.schedule()
+        now = time.time()
+        tmstps = []
         if schedule:
-            os.remove(self.filepath)
-            for redis_zset_key, infos in schedule.items():
-                timestamps = sorted(infos)
-                p = program.Program(
-                    *redis_zset_key.split(':')
-                    ).infos(timestamps[0])
-                factor = 0
-                for timestamp, path in p.items():
-                    # à chaque fois qu'on rencontre une occurence du fichier
-                    # on décrémente le facteur de multiplication de 1
-                    # pour que l'heure de début du programme
-                    # venant après ladite occurence
-                    # soit réduite de la bonne valeur
-                    if timestamp in timestamps:
-                        factor -= 1
-                        PROGRAMS.zrem(redis_zset_key, path)
-                    else:
-                        PROGRAMS.zincrby(
-                            redis_zset_key,
-                            path,
-                            (factor * duration)
-                            )
+            # os.remove(self.filepath)                                                                                                                                    
+            for key, tmstp in schedule.items():
+                t = [j for j in tmstp if j >= now]
+                tmstps += t
+            tmstps = sorted(list(set(tmstps)))
+
+            if not tmstp:
+                os.remove(self.filepath)
+                for redis_zset_key, infos in schedule.items():
+                    timestamps = sorted(infos)
+                    p = program.Program(
+                        *redis_zset_key.split(':')
+                         ).infos(timestamps[0])
+                    factor = 0
+                    for timestamp, path in p.items():
+                        # à chaque fois qu'on rencontre une occurence du fichier                                                                                          
+                        # on décrémente le facteur de multiplication de 1                                                                                                 
+                        # pour que l'heure de début du programme                                                                                                          
+                        # venant après ladite occurence                                                                                                                   
+                        # soit réduite de la bonne valeur                                                                                                                 
+                        if timestamp in timestamps:
+                            factor -= 1
+                            PROGRAMS.zrem(redis_zset_key, path)
+                        else:
+                            PROGRAMS.zincrby(
+                                redis_zset_key,
+                                path,
+                                (factor * duration)
+                                )
+            else:
+                raise ValueError('Cannot delete for it is scheduled')
         return
 
 
